package com.ykMap.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ykMap.base.controller.BaseController;
import com.ykMap.base.domain.AjaxResult;
import com.ykMap.entity.TaskMission;
import com.ykMap.service.TaskMissionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;

/**
 * 'task_mission(TaskMission)表控制层
 *
 * @author wu
 * @since 2024-09-19 13:15:12
 */
@RestController
@RequestMapping("/ykmap/taskMission")
@Api(tags = "'task_mission")
@Transactional(rollbackFor = Exception.class)
public class TaskMissionController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private TaskMissionService taskMissionService;

    /**
     * 分页条件查询所有数据
     *
     * @param page        分页条件
     * @param taskMission 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询'task_mission", response = TaskMission.class)
    public AjaxResult page(Page<TaskMission> page, TaskMission taskMission) {
        return success(taskMissionService.page(page, new QueryWrapper<>(taskMission)));
    }

    /**
     * 条件查询所有数据
     *
     * @param taskMission 查询条件
     * @return 所有数据
     */
    @GetMapping("/findAll")
    @ApiOperation(value = "条件查询'task_mission", response = TaskMission.class)
    public AjaxResult page(TaskMission taskMission) {
        return success(taskMissionService.list(new QueryWrapper<>(taskMission)));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条'task_mission", response = TaskMission.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return success(taskMissionService.getById(id));
    }


    /**
     * 根据车牌号查询
     *
     * @param plateNum 车牌号
     * @return 响应类
     */
    @GetMapping("findByPlateNum")
    @ApiOperation(value = "根据车牌号查询task_mission", response = TaskMission.class)
    public AjaxResult findByPlateNum(String plateNum) {
        return success(taskMissionService.findByPlateNum(plateNum));
    }

    /**
     * 根据多个车牌号查询task_mission
     *
     * @param plateNum 车牌号
     * @return 响应类
     */
    @GetMapping("findByPlateNums")
    @ApiOperation(value = "根据多个车牌号查询task_mission", response = TaskMission.class)
    public AjaxResult findByPlateNums(String plateNum) {
        return success(taskMissionService.findByPlateNums(plateNum));
    }

}

