package com.ykMap.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ykMap.entity.ColDTO;
import com.ykMap.entity.request.CarPageRequest;
import com.ykMap.entity.response.CarGPSResponse;
import com.ykMap.entity.response.CarPageResponse;
import com.ykMap.entity.response.ContentResponse;
import com.ykMap.exception.ServiceException;
import com.ykMap.service.CarService;
import com.ykMap.service.TaskMissionService;
import com.ykMap.utils.SpaceUtils;
import lombok.extern.slf4j.Slf4j;
import org.gavaghan.geodesy.GlobalCoordinates;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 车辆实时定位实现层
 *
 * @author wu
 * @since 2025/3/13 17:28
 */
@Service("CarService")
@Slf4j
public class CarServiceImpl implements CarService {

    @Resource
    private TaskMissionService taskMissionService;


    /**
     * 分页查询单位内外的车辆任务
     *
     * @param req 请求类
     * @return 响应类
     */
    @Override
    public ContentResponse page(CarPageRequest req) {
        // 查询sessionId
        String sessionId = findSessionId();
        // 获取车辆实时定位
        List<CarGPSResponse> carGPSList = findCarGPS(sessionId);
        GlobalCoordinates companyLocation = new GlobalCoordinates(31.226963,120.634355);
        // 过滤后的车辆
        List<CarGPSResponse> list = new ArrayList<>();
        if (CollectionUtil.isEmpty(carGPSList)) {
            return null;
        }
        for (CarGPSResponse res : carGPSList) {
            GlobalCoordinates carLocation = new GlobalCoordinates(Double.parseDouble(res.getLat()), Double.parseDouble(res.getLng()));
            double distanceMeter = SpaceUtils.getDistanceMeter(companyLocation, carLocation);
            if (req.getType() == 1) {
                if (NumberUtil.compare(req.getDistance(), distanceMeter) != 1) {
                    // 单位外
                    list.add(res);
                }
            } else {
                if (NumberUtil.compare(req.getDistance(), distanceMeter) == 1) {
                    // 单位内
                    list.add(res);
                }
            }
        }
        if (CollectionUtil.isEmpty(list)) {
            return null;
        }
        List<String> plateNums = list.stream().map(CarGPSResponse::getCarPlate).collect(Collectors.toList());
        Page<CarPageResponse> page = new Page<>();
        page.setCurrent(req.getPageNo());
        page.setSize(req.getPageSize());
        Page<CarPageResponse> carPageResponsePage = taskMissionService.pageByPlateNums(page, plateNums);
        ContentResponse contentResponse = new ContentResponse();
        contentResponse.setTotalCount(carPageResponsePage.getTotal());
        contentResponse.setPageNum(carPageResponsePage.getCurrent());
        contentResponse.setPageSize(carPageResponsePage.getSize());
        ArrayList<ColDTO> colDTOS = new ArrayList<>();
        ColDTO colDTO = new ColDTO();
        colDTO.setValue("carNumber");
        colDTO.setLabel("车辆号码");
        ColDTO colDTO2 = new ColDTO();
        colDTO2.setValue("Title");
        colDTO2.setLabel("任务名称");
        ColDTO colDTO3 = new ColDTO();
        colDTO3.setValue("addr");
        colDTO3.setLabel("车辆地址");
        ColDTO colDTO4 = new ColDTO();
        colDTO4.setValue("stateCn");
        colDTO4.setLabel("车辆状态");
        colDTOS.add(colDTO);
        colDTOS.add(colDTO2);
        colDTOS.add(colDTO3);
        colDTOS.add(colDTO4);
        contentResponse.setCol(colDTOS);
        // 将第一个列表转换为Map，以getCarPlate为键
        Map<String, CarGPSResponse> map1 = list.stream()
                .collect(Collectors.toMap(CarGPSResponse::getCarPlate, car -> car));
        // 遍历第二个列表，找到匹配的carNumber并赋值addr和stateCn
        for (CarPageResponse car2 : carPageResponsePage.getRecords()) {
            CarGPSResponse car1 = map1.get(car2.getCarNumber());
            if (car1 != null) {
                car2.setAddr(car1.getAddr());
                car2.setStateCn(car1.getStateCn());
            }
        }
        contentResponse.setData(carPageResponsePage.getRecords());
        return contentResponse;
    }

    /**
     * 获取sessionId
     *
     * @return sessionId
     */
    private String findSessionId() {
        String body = HttpRequest.get("http://192.168.0.91/gps-web/api/login.jsp")
                .form("userId", 99999)
                .form("password", "6d0fd76ab81325588d8065ec1036fdd3")
                .form("loginType", "user")
                .execute().body();
        JSONObject json;
        log.info("================获取sessionId数据=================");
        log.info(body);
        try {
            json = JSONObject.parse(body);
        } catch (Exception e) {
            log.error(e.getMessage());
            throw new ServiceException("未获取到sessionId");
        }
        return json.get("sessionId").toString();
    }

    /**
     * 获取车辆实时定位
     *
     * @return 车辆实时数据
     */
    private List<CarGPSResponse> findCarGPS(String sessionId) {
        String body = HttpRequest.get("http://192.168.0.91/gps-web/api/get_gps_r.jsp")
                .form("teamId", 2)
                .form("sessionId", sessionId)
                .execute().body();
        JSONObject json;
        log.info("================获取车辆实时定位数据=================");
        log.info(body);
        try {
          json = JSONObject.parse(body);
        } catch (Exception e) {
            log.error(e.getMessage());
            throw new ServiceException("获取车辆实时定位失败");
        }
        List<CarGPSResponse> list = Collections.emptyList();
        Object listStr = json.get("list");
        String recordsStr = JSONUtil.toJsonStr(listStr);
        if (StrUtil.isNotEmpty(recordsStr)) {
            // 获取所有车辆经纬度
            list = JSONUtil.toList(recordsStr, CarGPSResponse.class);

        }
        return list;
    }

}
