package com.ykMap.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ykMap.entity.TaskMission;
import com.ykMap.entity.response.CarPageResponse;
import com.ykMap.mapper.TaskMissionMapper;
import com.ykMap.service.TaskMissionService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 'task_mission(TaskMission)表服务实现类
 *
 * @author wu
 * @since 2024-09-19 13:15:13
 */
@Service("taskMissionService")
public class TaskMissionServiceImpl extends ServiceImpl<TaskMissionMapper, TaskMission> implements TaskMissionService {

    /**
     * 根据车牌号查询
     *
     * @param plateNum 车牌号
     * @return 响应类
     */
    @Override
    public TaskMission findByPlateNum(String plateNum) {
        return baseMapper.findByPlateNum(plateNum);
    }

    /**
     * 根据多个车牌号查询task_mission
     *
     * @param plateNum 车牌号
     * @return 响应类
     */
    @Override
    public List<TaskMission> findByPlateNums(String plateNum) {
        String[] split = plateNum.split(",");
        if (split.length > 0) {
            return baseMapper.findByPlateNums(split);
        } else {
            return null;
        }

    }

    /**
     * 根据车牌号分页查询车辆任务
     *
     * @param page      分页条件
     * @param plateNums 车牌号集合
     * @return 响应类
     */
    @Override
    public Page<CarPageResponse> pageByPlateNums(Page<CarPageResponse> page, List<String> plateNums) {
        return baseMapper.pageByPlateNums(page,plateNums);
    }
}

